@@ -229,7 +229,7 @@ def parse_essence(eprime, eprimeparam):
 
     for v in SortedSet(varmap.keys()).intersection(SortedSet(cons.keys())):
         # Only want matching '1'
-        for k in set(varmap[v].keys()):
+        for k in SortedSet(varmap[v].keys()):
             # This should be a boolean -- if this fails, check with Chris
             assert set(varmap[v][k].keys()).issubset(SortedSet([0, 1]))
 
